unit UAnalogIN_Counter;

interface

implementation

uses
  SysUtils,
  ConsoleHelper,
  MAI_v2_DLL;


var
	CardID,  SizeOfLastBlockRead,  ValuesPerChannel ,TTLBlockSizeTemp, NumberOfADChannels,NumberOfCTChannels, CurrentNumberOfADValues,currentNumberOfCTValues,MaxValuesToGet,ValuesInFifo: Cardinal;
  i,Result                : Integer;
  KeyThatWasPressed       : AnsiChar;
  StreamingMode           : TStreamingMode;
  RawData		              : array of Integer;
  CounterData             : array of Integer;
	ScaledData              : array of Double;
  ADAnzeige               : array of Double;
  CTAnzeige               : array of Integer;
  CounterTye              : TCounterMode;

begin
//////////////////////////////////////////////////////////////////////////////////////////////
//  Parameter der Messung	                                                       						//
//////////////////////////////////////////////////////////////////////////////////////////////
 	TTLBlockSizeTemp	   	:= 0;
  NumberOfADChannels		:= 2;
  NumberOfCTChannels    := 1;
  ValuesPerChannel		  := 100;
  MaxValuesToGet        := 10000;
  CounterTye            := cmIMPULSECOUNTER;

	SetLength(RawData,    ValuesPerChannel);
	SetLength(ScaledData ,ValuesPerChannel);
	SetLength(CounterData,ValuesPerChannel);

	SetLength(ADAnzeige, NumberOfADChannels);
	SetLength(CTAnzeige, NumberOfCTChannels);

//////////////////////////////////////////////////////////////////////////////////////////////
//  CardID der ersten, verfgbaren Karte verwenden	                             						//
//////////////////////////////////////////////////////////////////////////////////////////////
  CardID := GetFirstDevice();
	if (CardID < 0) then
	begin
		PrintError(CardID, CardID);
	 	Exit;
	end;

  WriteLn('Verwende Karte mit ID 0.');
  Writeln('Serial Number : '+GetSerialNumber(CardID));            // Seriennummer der Karte

  Writeln;
  Result := ClearAllChannelLists(CardID) ;
  if (Result <> 0) then
  begin
			PrintError(CardID, Result);
      Exit;
	end;

//////////////////////////////////////////////////////////////////////////////////////////////
// Kanle der Kanalliste hinzufgen									                             						//
//////////////////////////////////////////////////////////////////////////////////////////////
	for i := 0 to NumberOfADChannels-1 do
	begin
		Result := AD_AddChannelToList(	CardID,												// ID der anzusprechenden Karte
                                    i,												  	// Kanalnummer
                                    oversamplingDISABLED,										// Funktion um Strungen des Messsignals zu reduzieren
                                    gainDisabled,										// Verstrkungsfaktor
                                    polBIPOLAR  );									// ein Wechsel der Polatitt wird vom Basic-Karten nicht untersttzt

		if (Result <> 0) then 																	      // Fehler prfen
		begin
			PrintError(CardID, Result);
      Exit;
		end;
	end;

	for i := 0 to NumberOfCTChannels-1 do
	begin
 		Result := CT_AddChannelToList(	CardID,											// ID der anzusprechenden Karte
										                i,							  					// Kanalnummer
                                    true);                      // Synchron zur AD Kanalliste    if (Result <> 0) then
    if (Result <> 0) then
    begin
      PrintError(CardID, Result);
      Exit;
    end;
		case (CounterTye) of

      cmFREQUENCYCOUNTER:
        Result := CT_FrequencyCounter(	CardID,											// ID der verwendeten Karte
                                        i,												// Eintrag des Kanals in die Kanalliste
                                        0,												// Frequenzauflsung; 0 - 1Hz, 1 - 10Hz, 2 - 100Hz, 3 - 1000Hz
                                        0,												// Flanke des zu triggernden Eingangssignals
                                        0);												// EachPeriod


      cmPERIODCOUNTER:
        Result := CT_PeriodCounter(		CardID,											// ID der Karte
                                      i,												// Kanallisteneintrag
                                      0,												// Frequenzauflsung
                                      0,												// Flanke
                                      0);												// EachPeriod


      cmPULSWIDTHCOUNTER:
        Result := CT_PulswidthCounter(	CardID,											// ID
                                        i,												// Kanallisteneintrag
                                        0,												// Frequenzauflsung
                                        0,												// Flanke
                                        0);												// EachPeriod


      cmINCREMENTALCOUNTER:
        Result := CT_IncrementalCounter(	CardID,											// ID der verwendeten Karte
                                          i,												// Eintrag des Kanals in die Kanalliste
                                          0,												// Auflsung des HardwareCounters; beeinflut interne Auflsung zwischen 100ns und 20ns
                                          0,												// Flanke
                                          0,												// SoftwareReset setzt aktuellen Zhlwert zurck
                                          0,												// HardwareReset; 0 - Disabled, 1 - LevelMode, 2 - Extendet LevelMode, 3 - EdgeMode
                                          0,												// Flanke des Eingangssignals, auf die am Reseteingang getriggert werden soll
                                          0);												// Interpolation; 0 - 1x, 1 - 2x, 2 - 4x


      else
        Result := CT_ImpulseCounter(		CardID,											// ID der Karte
                                        i,												// Eintrag des Kanals in die Kanalliste
                                        0,												// Startwert der Zhlermessung
                                        0,												// legt fest, ob hoch oder runter gezhlt werden soll
                                        0);												// Flanke
    end;
    if (Result <> 0) then
    begin
      PrintError(CardID, Result);
      Exit;
    end;
	end;

//////////////////////////////////////////////////////////////////////////////////////////////
// Frequenzen setzen																			                                    //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := AD_SetFrequency(	CardID,
								              1000   );											    	// Abtastrate pro Kanal
	if (Result <> 0) then 																		        // Fehler prfen
	begin
	  PrintError(CardID, CardID);
	 	Exit;
	end;
	Result := CT_SetFrequency(	CardID,
								              1000   );											    	// Abtastrate pro Kanal
	if (Result <> 0) then 																		        // Fehler prfen
	begin
	  PrintError(CardID, CardID);
	 	Exit;
	end;




//////////////////////////////////////////////////////////////////////////////////////////////
// Parametrieren der Karte und Verarbeitung aller zuvor gettigten Eingaben / Einstellungen //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := ConfigMeasure(CardID);
	if (Result <> 0) then
	begin
      PrintError(CardID, CardID);
	 	  Exit;
	end;


//////////////////////////////////////////////////////////////////////////////////////////////
// Messung starten																		                                    //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := StartMeasure(CardID);
	if (Result <> 0) then
	begin
     PrintError(CardID, CardID);
     Exit;
	end;




//////////////////////////////////////////////////////////////////////////////////////////////
// Messdaten abholen																		                                    //
//////////////////////////////////////////////////////////////////////////////////////////////

  CurrentNumberOfADValues := 0;
  CurrentNumberOfCTValues := 0;

	while (CurrentNumberOfADValues < MaxValuesToGet) do 											// Bedingung fr Beendigung der Schleife
	begin
    if (KeyPressed(KeyThatWasPressed)) then
    begin
        if(KeyThatWasPressed = #27) then
        begin
           WriteLn('Sie haben <ESC> gedrueckt.');
				   break;
        end;

    end;
    Result := AD_GetNumberOfValues(CardID, ValuesInFifo);										// gibt Anzahl der in den Fifos befindlichen Werte zurck
		if (Result <> 0) then
		begin
      PrintError(CardID, Result);
      break;
		end;
    /////////////////////////////////////////////////////////////////////////
    // Analogdaten abholen										                             //
    /////////////////////////////////////////////////////////////////////////
		if (ValuesInFifo >= ValuesPerChannel) then 														// wenn gengend Werte vorliegen
		begin

      SizeOfLastBlockRead :=  ValuesPerChannel;

				for i := 0 to NumberOfADChannels-1 do									// jeder ADKanal wird durchlaufen
				begin

					Result := AD_ReadData(	CardID,											 // ID der verwendeten Karte
                                  i,												   // Nummer des Kanallisteneintrages (Grund: Wird ein Kanal mehrmals in die Kanalliste aufgenommen, muss zur Unterscheidung die Nummer des Kanallisteneintrages angegeben werden.)
                                  @RawData[0],								 // Rohdaten
                                  @ScaledData[0],							 // Skalierte Daten
                                  SizeOfLastBlockRead,				 // Anzahl der Werte
                                  partONLYFULLBLOCKS,						 // Ganze Blcke / Teilblcke	(0 - ganz , 1 - teil)
                                  skipGETCAPTUREDVALUES    );		 // Erfasste Werte verwerfen		(0 - false, 1 - true)
					if (Result <> 0) then
					begin
              PrintError(CardID, Result);
              break;
					end;

					ADAnzeige[i] := ScaledData[0];											// der jeweilig erste Werte wird zur Ausgabe auf der Konsole bereitgestellt
				end;

      CurrentNumberOfADValues := CurrentNumberOfADValues + SizeOfLastBlockRead;				// Zhler fr die Anzahl der erfassten Werte


		end;
    /////////////////////////////////////////////////////////////////////////
    // Counterdaten abholen										                             //
    /////////////////////////////////////////////////////////////////////////
    Result := CT_GetNumberOfValues(CardID, ValuesInFifo);
		if (Result <> 0) then
		begin
      PrintError(CardID, Result);
      break;
		end;

		if (ValuesInFifo >= ValuesPerChannel) then
		begin

      SizeOfLastBlockRead :=  ValuesPerChannel;

				for i := 0 to NumberOfCTChannels-1 do									// jeder ADKanal wird durchlaufen
				begin

					Result := CT_ReadData(	CardID,											 // ID der verwendeten Karte
                                  i,												   // Nummer des Kanallisteneintrages (Grund: Wird ein Kanal mehrmals in die Kanalliste aufgenommen, muss zur Unterscheidung die Nummer des Kanallisteneintrages angegeben werden.)
                                  @CounterData[0],								   // Daten
                                  SizeOfLastBlockRead,				 // Anzahl der Werte
                                  partONLYFULLBLOCKS,						 // Ganze Blcke / Teilblcke	(0 - ganz , 1 - teil)
                                  skipGETCAPTUREDVALUES    );		 // Erfasste Werte verwerfen		(0 - false, 1 - true)
					if (Result <> 0) then
					begin
              PrintError(CardID, Result);
              break;
					end;

					CTAnzeige[i] := CounterData[0];											// der jeweilig erste Werte wird zur Ausgabe auf der Konsole bereitgestellt
				end;

     currentNumberOfCTValues := currentNumberOfCTValues + SizeOfLastBlockRead;				// Zhler fr die Anzahl der erfassten Werte


		end;
     Write(Char(13)+'  ' + InttoStr( currentNumberOfADValues )+ ' CT:'+ InttoStr( currentNumberOfCTValues )+' von ' + InttoStr( MaxValuesToGet )+',  Volt: ');
      for i := 0 to  NumberOfADChannels-1 do
      begin
          Write(FloatToStrF( ADAnzeige[i],ffFixed, 4, 2) );
          Write(' ');
      end;
       Write(', CT:');
      for i := 0 to  NumberOfCTChannels-1 do
      begin
          Write(InttoStr( CTAnzeige[i]) );
          Write(' ');
      end;
      Write('            ');
      Sleep(1);
	end;

  //////////////////////////////////////////////////////////////////////////////////////////////
  // Messung anhalten																			                                    //
  //////////////////////////////////////////////////////////////////////////////////////////////
	Result := StopMeasure(CardID);
	if (Result <> 0) then
	begin
    PrintError(CardID, CardID);
    Exit;
	end;

  WriteLn;
  WriteLn;
  Writeln('Fertig. (Bitte <Enter> druecken...)');
  Read(KeyThatWasPressed);
end.
