unit UCardAttributes;

interface

implementation
uses
  SysUtils,
  ConsoleHelper,
  MAI_v2_DLL;

var
  CardID                  : Cardinal;
  i,Result                : Integer;
  KeyThatWasPressed       : Char;

	SystemVersion           : AnsiString;
  ControllerFwVersion	    : Integer;
	MPVersion			          : Integer;
	MAIVersion			        : PAnsiChar;
	CardName				        : PAnsiChar;
	CardProducer		        : PAnsiChar;
	CardSeller				      : PAnsiChar;
	ManufactureName		      : PAnsiChar;
	SerialNumber		        : PAnsiChar;
	CustomerName		        : PAnsiChar;
	CustomerNumber	        : PAnsiChar;
	CustomerPurchase	      : PAnsiChar;

	ADNumberOfChannels	    : Integer;
	ADSampleRate			      : Integer;
	ADSampleWidth			      : Integer;
	DANumberOfChannels	    : Integer;
	DASampleRate		   	    : Integer;
	DASampleWidth			      : Integer;
	TTLNumberOfChannels		  : Integer;
	TTLSampleRate			      : Integer;
	TTLSampleWidth		      : Integer;
	CTNumberOfChannels	    : Integer;
	CTSampleRate		        : Integer;
	CTSampleWidth       	  : Integer;


begin
//////////////////////////////////////////////////////////////////////////////////////////////
//  CardID der ersten, verfgbaren Karte verwenden	                             						//
//////////////////////////////////////////////////////////////////////////////////////////////
  CardID := GetFirstDevice();
	if (CardID < 0) then
	begin
		PrintError(CardID, CardID);
	 	Exit;
	end;
  SystemVersion := '                            ';
//////////////////////////////////////////////////////////////////////////////////////////////
// Versionsnummern auslesen			 														                                //
//////////////////////////////////////////////////////////////////////////////////////////////
	MAIVersion := GetLIBVersion();															        // Version des verwendeten Treibers
  GetSystemDriverVersion(CardID, @SystemVersion[1]);											// Systemtreiberversion
	ControllerFwVersion	:= GetControllerFirmwareVersion(CardID);				// ControllerVersion
	MPVersion := GetMeasurementProcessorVersion(CardID);								// Version des MeasurementProcessors
	CardName := GetCardName(CardID);															      // Kartenname
	CardProducer := GetCardProducer(CardID);													  // Hersteller
	CardSeller := GetCardSeller(CardID);														    // Verkufer
	ManufactureName := GetManufacture_Name(CardID);											// Kartentyp
	SerialNumber := GetSerialNumber(CardID);													  // Seriennummer
	CustomerName := GetCustomer_Name(CardID);												    // Name des Kufers
	CustomerNumber := GetCustomer_Number(CardID);											  // Kufernummer
	CustomerPurchase := GetCustomer_DateOfPurchase(CardID);							// Datum des Verkaufs    


//////////////////////////////////////////////////////////////////////////////////////////////
// Attribute abfragen																		                                       //
//////////////////////////////////////////////////////////////////////////////////////////////
	ADNumberOfChannels := GetADChannels(CardID);												// Anzahl der analogen Eingabekanle auf der Karte
	ADSampleRate := GetADSampleRate(CardID);													  // Summenabtastrate der AD-Kanle
	ADSampleWidth := GetADSampleWidth(CardID);												  // Bitbreite der AD-Kanle
	DANumberOfChannels := GetDAChannels(CardID);												// Anzahl der analogen Ausgabekanle
	DASampleRate := GetDASampleRate(CardID);													  // maximale Ausgabefrequenz der Karte
	DASampleWidth := GetDASampleWidth(CardID);												  // Bitbreite der DA-Kanle
	TTLNumberOfChannels := GetTTLChannels(CardID);											// Anzahl der digitalen Kanle
	TTLSampleRate := GetTTLSampleRate(CardID);												  // maximale Frequenz
	TTLSampleWidth := GetTTLSampleWidth(CardID);												// Bitbreite
	CTNumberOfChannels := GetCTChannels(CardID);												// Anzahl der Zhler
	CTSampleRate := GetCTSampleRate(CardID);													  // Frequenz
	CTSampleWidth := GetCTSampleWidth(CardID);												  // Bit

//////////////////////////////////////////////////////////////////////////////////////////////
// Ausgabe der Werte auf der Konsole														                            //
//////////////////////////////////////////////////////////////////////////////////////////////
  ClearScreen;
  WriteLn(' VERSIONSNUMMERN                                             (Seite 1/2)');
  WriteLn;
  WriteLn;
  Writeln(' Version der verwendeten MAI Lib:  '+MAIVersion);
  Writeln(' Version des Systemtreibers     :  '+SystemVersion);
  Writeln(' FirmwareVersion (Controller)   :  '+IntToStr(ControllerFwVersion)+  '  (' +IntToHex(ControllerFwVersion,1)+')');
  Writeln(' MeasurementProcessorVersion    :  '+IntToHex(MPVersion,1));
  WriteLn;
  WriteLn;
  Writeln(' Kartenname:        ' + CardName);
  Writeln(' Hersteller:        ' + CardProducer);
  Writeln(' Verkaeufer:        ' + CardSeller);
  Writeln(' Kartentyp:         ' + ManufactureName);
  Writeln(' Seriennummer:      ' + SerialNumber);
  Writeln(' Name des Kaeufers: ' + CustomerName);
  Writeln(' Kaeufernummer:     ' + CustomerNumber);
  Writeln(' Kaufdatum:         ' + CustomerPurchase);
  WriteLn;
  WriteLn;
  Writeln('(Bitte <Enter> druecken...)');
  ReadLn(KeyThatWasPressed);
  ClearScreen;
  WriteLn(' ANALOGE EINGABEKANAELE                                      (Seite 2/2)');
  WriteLn(' Anzahl          : '+InttoStr(ADNumberOfChannels));
  WriteLn(' Summenabtastrate: '+InttoStr(ADSampleRate)+ ' kHz');
  WriteLn(' Bitbreite       : '+InttoStr(ADSampleWidth)+ ' Bit');
  WriteLn;
  WriteLn(' ANALOGE AUSGABEKANAELE ');
  WriteLn(' Anzahl          : '+InttoStr(DANumberOfChannels));
  WriteLn(' Ausgabefrequenz : '+InttoStr(DASampleRate)+ ' kHz');
  WriteLn(' Bitbreite       : '+InttoStr(DASampleWidth)+ ' Bit');
  WriteLn;
  WriteLn(' DIGITALE KANAELE');
  WriteLn(' Anzahl    :       '+InttoStr(TTLNumberOfChannels));
  WriteLn(' SampleRate:       '+InttoStr(TTLSampleRate)+ ' kHz');
  WriteLn(' Bitbreite :       '+InttoStr(TTLSampleWidth)+ ' Bit');
  WriteLn;
  WriteLn(' ZAEHLER');
  WriteLn(' Anzahl    :       '+InttoStr(CTNumberOfChannels));
  WriteLn(' SampleRate:       '+InttoStr(CTSampleRate)+ ' kHz');
  WriteLn(' Bitbreite :       '+InttoStr(CTSampleWidth)+ ' Bit');

  WriteLn;
  WriteLn;
  Writeln('Fertig. (Bitte <Enter> druecken...)');
  Readln(KeyThatWasPressed);

end.
