unit UCounter;

interface

implementation

uses
  SysUtils,
  ConsoleHelper,
  MAI_v2_DLL;


var
	CardID, SizeOfLastBlockRead,  ValuesPerChannel , NumberOfCTChannels, CurrentNumberOfValues,MaxValuesToGet,ValuesInFifo: Cardinal;
  i,Result                : Integer;
  KeyThatWasPressed       : AnsiChar;
  CTData		              : array of Cardinal;
  CTAnzeige               : array of Cardinal;
  CounterTye              : TCounterMode;

begin
//////////////////////////////////////////////////////////////////////////////////////////////
//  Parameter der Messung	                                                       						//
//////////////////////////////////////////////////////////////////////////////////////////////
  NumberOfCTChannels		:= 2;
  ValuesPerChannel		  := 20;
  MaxValuesToGet        := 10000;
  CounterTye            := cmIMPULSECOUNTER;
	SetLength(CTData,   ValuesPerChannel);
	SetLength(CTAnzeige, NumberOfCTChannels);
//////////////////////////////////////////////////////////////////////////////////////////////
//  CardID der ersten, verfgbaren Karte verwenden	                             						//
//////////////////////////////////////////////////////////////////////////////////////////////
  CardID := GetFirstDevice();
	if (CardID < 0) then
	begin
		PrintError(CardID, CardID);
	 	Exit;
	end;

  WriteLn('Verwende Karte mit ID 0.');
  Writeln('Serial Number : '+GetSerialNumber(CardID));            // Seriennummer der Karte
  WriteLn;
  
//////////////////////////////////////////////////////////////////////////////////////////////
// Kanallisten lschen																		                                   //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := ClearAllChannelLists(CardID);													// lscht softwareseitig gehaltene Kanallisten
	if (Result <> 0) then
	begin
		PrintError(CardID, CardID);
	 	Exit;
 	end;

//////////////////////////////////////////////////////////////////////////////////////////////
// Kanle der Kanalliste hinzufgen									                             						//
//////////////////////////////////////////////////////////////////////////////////////////////
	for i := 0 to NumberOfCTChannels-1 do
	begin
		Result := CT_AddChannelToList(	CardID,											// ID der anzusprechenden Karte
										                i,							  					// Kanalnummer
                                    false);                      // Synchron zur AD Kanalliste
    if (Result <> 0) then
    begin
      PrintError(CardID, CardID);
      Exit;
    end;
  end;
	for i := 0 to NumberOfCTChannels-1 do
	begin
		case (CounterTye) of

      cmFREQUENCYCOUNTER:
        Result := CT_FrequencyCounter(	CardID,											// ID der verwendeten Karte
                                        i,												// Eintrag des Kanals in die Kanalliste
                                        0,												// Frequenzauflsung; 0 - 1Hz, 1 - 10Hz, 2 - 100Hz, 3 - 1000Hz
                                        0,												// Flanke des zu triggernden Eingangssignals
                                        0);												// EachPeriod


      cmPERIODCOUNTER:
        Result := CT_PeriodCounter(		CardID,											// ID der Karte
                                      i,												// Kanallisteneintrag
                                      0,												// Frequenzauflsung
                                      0,												// Flanke
                                      0);												// EachPeriod


      cmPULSWIDTHCOUNTER:
        Result := CT_PulswidthCounter(	CardID,											// ID
                                        i,												// Kanallisteneintrag
                                        0,												// Frequenzauflsung
                                        0,												// Flanke
                                        0);												// EachPeriod


      cmINCREMENTALCOUNTER:
        Result := CT_IncrementalCounter(	CardID,											// ID der verwendeten Karte
                                          i,												// Eintrag des Kanals in die Kanalliste
                                          0,												// Auflsung des HardwareCounters; beeinflut interne Auflsung zwischen 100ns und 20ns
                                          0,												// Flanke
                                          0,												// SoftwareReset setzt aktuellen Zhlwert zurck
                                          0,												// HardwareReset; 0 - Disabled, 1 - LevelMode, 2 - Extendet LevelMode, 3 - EdgeMode
                                          0,												// Flanke des Eingangssignals, auf die am Reseteingang getriggert werden soll
                                          0);												// Interpolation; 0 - 1x, 1 - 2x, 2 - 4x


      else
        Result := CT_ImpulseCounter(		CardID,											// ID der Karte
                                        i,												// Eintrag des Kanals in die Kanalliste
                                        0,												// Startwert der Zhlermessung
                                        0,												// legt fest, ob hoch oder runter gezhlt werden soll
                                        0);												// Flanke


    end;
    if (Result <> 0) then
    begin
      PrintError(CardID, Result);
      Exit;
    end;
	end;

//////////////////////////////////////////////////////////////////////////////////////////////
// Frequenz setzen																			                                    //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := CT_SetFrequency(	CardID,
								              1000   );											    	// Abtastrate pro Kanal
	if (Result <> 0) then 																		        // Fehler prfen
	begin 
	  PrintError(CardID, Result);
	 	Exit;
	end;

 	Result := AD_SetFrequency(	CardID,
								              1000   );											    	// Abtastrate pro Kanal
	if (Result <> 0) then 																		        // Fehler prfen
	begin
	  PrintError(CardID, Result);
	 	Exit;
	end;


//////////////////////////////////////////////////////////////////////////////////////////////
// Parametrieren der Karte und Verarbeitung aller zuvor gettigten Eingaben / Einstellungen //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := ConfigMeasure(CardID);
	if (Result <> 0) then
	begin
      PrintError(CardID, Result);
	 	  Exit;
	end;


//////////////////////////////////////////////////////////////////////////////////////////////
// Messung anstarten																		                                    //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := StartMeasure(CardID);
	if (Result <> 0) then
	begin
     PrintError(CardID, CardID);
     Exit;
	end;



//////////////////////////////////////////////////////////////////////////////////////////////
// Messdaten abholen																		                                    //
//////////////////////////////////////////////////////////////////////////////////////////////

  CurrentNumberOfValues := 0;
	while (CurrentNumberOfValues < MaxValuesToGet) do 											// Bedingung fr Beendigung der Schleife
	begin
    if (KeyPressed(KeyThatWasPressed)) then
    begin
        if(KeyThatWasPressed = #27) then
        begin
           WriteLn('Sie haben <ESC> gedrueckt.');
				   break;
        end;

    end;
    Result := CT_GetNumberOfValues(CardID, ValuesInFifo);										// gibt Anzahl der in den Fifos befindlichen Werte zurck
		if (Result <> 0) then
		begin
      PrintError(CardID, Result);
      break;
		end;

		if (ValuesInFifo >= ValuesPerChannel) then 														// wenn gengend Werte vorliegen
		begin

				for i := 0 to NumberOfCTChannels-1 do									// jeder ADKanal wird durchlaufen
				begin
          SizeOfLastBlockRead :=  ValuesPerChannel;

					Result := CT_ReadData(	CardID,											 // ID der verwendeten Karte
                                  i,												   // Nummer des Kanallisteneintrages (Grund: Wird ein Kanal mehrmals in die Kanalliste aufgenommen, muss zur Unterscheidung die Nummer des Kanallisteneintrages angegeben werden.)
                                  @CTData[0],								   // Daten
                                  SizeOfLastBlockRead,				 // Anzahl der Werte
                                  partONLYFULLBLOCKS,						 // Ganze Blcke / Teilblcke	(0 - ganz , 1 - teil)
                                  skipGETCAPTUREDVALUES    );		 // Erfasste Werte verwerfen		(0 - false, 1 - true)
					if (Result <> 0) then
					begin
              PrintError(CardID, Result);
              break;
					end;

					CTAnzeige[i] := CTData[0];											// der jeweilig erste Werte wird zur Ausgabe auf der Konsole bereitgestellt
					CurrentNumberOfValues := CurrentNumberOfValues + SizeOfLastBlockRead;				// Zhler fr die Anzahl der erfassten Werte
				end;
			end;



      Write(Char(13)+'  ' + InttoStr( currentNumberOfValues )+ '/' + InttoStr( MaxValuesToGet )+'     Zaehlerstaende : ');
      for i := 0 to  NumberOfCTChannels-1 do
      begin
          Write(IntToStr( CTAnzeige[i]) );
          Write('    ');
      end;
    Sleep(1);
  end;



  //////////////////////////////////////////////////////////////////////////////////////////////
  // Messung anhalten																			                                    //
  //////////////////////////////////////////////////////////////////////////////////////////////
	Result := StopMeasure(CardID);
	if (Result <> 0) then
	begin
    PrintError(CardID, CardID);
    Exit;
	end;

  WriteLn;
  WriteLn;
  Writeln('Fertig. (Bitte <Enter> druecken...)');
  Read(KeyThatWasPressed);
end.
