unit UFFT;

interface

implementation

uses
  SysUtils,
  ConsoleHelper,
  MAI_v2_DLL;


var
	CardID,  SizeOfLastBlockRead,  ValuesPerChannel, CurrentNumberOfValues,MaxValuesToGet,ValuesInFifo,nCardsSWExtensions, DummyIndex: Cardinal;
  i,Result                : Integer;
  KeyThatWasPressed       : AnsiChar;
  RawData		              : array of Integer;
	ScaledData              : array of Double;
  IIRnotFIR               : Boolean;
  SampleRate              : Double;
  SpecSize                : Cardinal;
	FFTSpectrum             : array of Double;

begin
//////////////////////////////////////////////////////////////////////////////////////////////
//  Parameter der Messung	                                                       						//
//////////////////////////////////////////////////////////////////////////////////////////////
  ValuesPerChannel		  := 200;
  MaxValuesToGet        := 100000;
  IIRnotFIR             := True;
  SampleRate            := 5000;
 	SetLength(FFTSpectrum,4096);

//////////////////////////////////////////////////////////////////////////////////////////////
//  CardID der ersten verfgbaren Karte verwenden	                              						//
//////////////////////////////////////////////////////////////////////////////////////////////
  CardID := GetFirstDevice();
	if (CardID < 0) then
	begin
		PrintError(CardID, CardID);
	 	Exit;
	end;
//////////////////////////////////////////////////////////////////////////////////////////////
// Prfen, ob Filter SW Extension aktiviert ist   										                          //
//////////////////////////////////////////////////////////////////////////////////////////////
	nCardsSWExtensions := 0;
	Result := GetSoftwareExtension(CardID,nCardsSWExtensions);
  if (Result <> 0) then
  begin
			PrintError(CardID, Result);
      Exit;
	end;
	if(((nCardsSWExtensions shr Cardinal(swxOnline_FFT))and 1)=0) then // Masking the Bit for desired Function
  begin
    WriteLn;
    Writeln('Diese Karte hat keine FFT SW Extension installiert. (Bitte <Enter> druecken...)');
    Read(KeyThatWasPressed);
    Exit;
	end;

  WriteLn('Verwende Karte mit ID 0.');
  Writeln('Serial Number : '+GetSerialNumber(CardID));            // Seriennummer der Karte

  Result := ClearAllChannelLists(CardID) ;
  if (Result <> 0) then
  begin
			PrintError(CardID, Result);
      Exit;
	end;
//////////////////////////////////////////////////////////////////////////////////////////////
// AD Kanal der Kanalliste hinzufgen									                             						//
//////////////////////////////////////////////////////////////////////////////////////////////


		Result := AD_AddChannelToList(	CardID,												// ID der anzusprechenden Karte
                                    0,												  	// Kanalnummer
                                    oversamplingDISABLED,					// Funktion um Strungen des Messsignals zu reduzieren
                                    gainDisabled,									// Verstrkungsfaktor
                                    polBIPOLAR  );								// ein Wechsel der Polatitt wird vom Basic-Karten nicht untersttzt

		if (Result <> 0) then 																	      // Fehler prfen
		begin
			PrintError(CardID, Result);
      Exit;
		end;


//////////////////////////////////////////////////////////////////////////////////////////////
// Frequenz setzen																			                                    //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := AD_SetFrequency(	CardID,
								              SampleRate   );						 			    	// Abtastrate
	if (Result <> 0) then 																		        // Fehler prfen
	begin
	  PrintError(CardID, CardID);
	 	Exit;
	end;

//////////////////////////////////////////////////////////////////////////////////////////////
// FFT Funktion hinzufgen				 										            //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := Realtime_AddFFTEntry(CardID,   // Card ID
										0,  // Number of AD Channel in Channellist
										fft_s512,  // Size of FFT Spectrum
										fftAbsolute,  // Type of FFT Spectrum 
										1,  // Gain Factor
										firwinRectangular,  // Window Function (Rectangular in FFT Analyzers means: NO FILTER.   
										0,  // Window Function Factor (not used with simple Window Functions)
										DummyIndex);  // Out : Handle to the generated On-Card Online-Function (Some Cards/Functions allow later Change)

	if (Result <> 0) then 																		        // Fehler prfen
	begin
	  PrintError(CardID, CardID);
	 	Exit;
	end;

//////////////////////////////////////////////////////////////////////////////////////////////
// Parametrieren der Karte und Verarbeitung aller zuvor gettigten Eingaben / Einstellungen //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := ConfigMeasure(CardID);
	if (Result <> 0) then
	begin
      PrintError(CardID, CardID);
	 	  Exit;
	end;


//////////////////////////////////////////////////////////////////////////////////////////////
// Messung anstarten																		                                    //
//////////////////////////////////////////////////////////////////////////////////////////////
	Result := StartMeasure(CardID);
	if (Result <> 0) then
	begin
     PrintError(CardID, CardID);
     Exit;
	end;


	SetLength(RawData,   ValuesPerChannel);
	SetLength(ScaledData,ValuesPerChannel);

//////////////////////////////////////////////////////////////////////////////////////////////
// Messdaten abholen																		                                    //
//////////////////////////////////////////////////////////////////////////////////////////////

  CurrentNumberOfValues := 0;
	while (CurrentNumberOfValues < MaxValuesToGet) do 											// Bedingung fr Beendigung der Schleife
	begin
    if (KeyPressed(KeyThatWasPressed)) then
    begin
        if(KeyThatWasPressed = #27) then
        begin
           WriteLn('Sie haben <ESC> gedrueckt.');
				   break;
        end;

    end;
    Result := AD_GetNumberOfValues(CardID, ValuesInFifo);										// gibt Anzahl der in den Fifos befindlichen Werte zurck
		if (Result <> 0) then 
		begin
      PrintError(CardID, Result);
      break;
		end;

		if (ValuesInFifo >= ValuesPerChannel) then 														// wenn gengend Werte vorliegen
		begin 

        SizeOfLastBlockRead :=  ValuesPerChannel;

				Result := AD_ReadData(	CardID,											// ID der verwendeten Karte
                                0,													// 0, weil alles in einem Fifo
                                @RawData[0],							  // Rohdaten
                                @ScaledData[0],							 // Skalierte Daten
                                SizeOfLastBlockRead,				 // Anzahl der Werte
                                partONLYFULLBLOCKS,						 // Ganze Blcke / Teilblcke	(0 - ganz , 1 - teil)
                                skipGETCAPTUREDVALUES    );		 // Erfasste Werte verwerfen		(0 - false, 1 - true)
				if (Result <> 0) then
				begin
			   PrintError(CardID, Result);
         break;
				end;


				CurrentNumberOfValues := CurrentNumberOfValues + SizeOfLastBlockRead;					// Zhler fr die Anzahl der erfassten Werte
     	SpecSize := 4096;   // Size of allocated Buffer

			Result := Realtime_FFT_ReadData(CardID,0,@FFTSpectrum[0],SpecSize);
    	if (Result <> 0) then
				begin
			   PrintError(CardID, Result);
         break;
				end;
      ClearScreen;
      Writeln(InttoStr( currentNumberOfValues )+ '/' + InttoStr( MaxValuesToGet )+'     Voltage: '+ FloattoStr(  ScaledData[0])+ 'Spectrum (first 20 Points):');
			for  i := 1 to SpecSize do
      begin
			Writeln(FloatToStr( FFTSpectrum[i] ));
				if(i > 20) then
					break;
			end;

      Sleep(1);
		end;

	end;

  //////////////////////////////////////////////////////////////////////////////////////////////
  // Messung anhalten																			                                    //
  //////////////////////////////////////////////////////////////////////////////////////////////
	Result := StopMeasure(CardID);
	if (Result <> 0) then
	begin
    PrintError(CardID, CardID);
    Exit;
	end;

  WriteLn;
  WriteLn;
  Writeln('Fertig. (Bitte <Enter> druecken...)');
  Read(KeyThatWasPressed);
end.
